app/soc/models/group_app.py
changeset 1080 d533408811ba
parent 970 8b5611d5b053
child 1085 0afbdd0905ef
--- a/app/soc/models/group_app.py	Fri Jan 30 10:36:23 2009 +0000
+++ b/app/soc/models/group_app.py	Fri Jan 30 11:15:26 2009 +0000
@@ -98,9 +98,9 @@
   member_criteria.help_text = ugettext(
     'Members include mentors, admininstrators, and the like.')
 
   # property containing the status of the application
   # completed means that the application has been processed into a real group
-  status = db.StringProperty(required=True, 
+  state = db.StringProperty(required=True, 
       choices=['accepted','rejected','ignored','needs review','completed'],
       default='needs review',
       verbose_name=ugettext('Application Status'))
@@ -98,9 +98,9 @@
     'Members include mentors, admininstrators, and the like.')
 
-  # property containing the status of the application
+  # property containing the state of the application
   # completed means that the application has been processed into a real group